@@ -29,4 +29,5 @@
 
 (defpackage #:cffi-tests
   (:use #:cl #:cffi #:cffi-sys #:regression-test)
-  (:export #:do-tests #:run-cffi-tests #:run-all-cffi-tests))
+  (:export #:do-tests #:run-cffi-tests #:run-all-cffi-tests)
+  (:shadow #:deftest))
